@@ -1,7 +1,7 @@
 """Initialize the package."""
 from pystibmivb.client import AbstractSTIBAPIClient, STIBAPIClient
 from pystibmivb.service import STIBService, InvalidLineFilterException, NoScheduleFromAPIException
-from pystibmivb.service import ShapefileService
+from pystibmivb.service import ShapefileService, InvalidStopNameException
 from .domain import *
 
 NAME = "pystibmivb"
\ No newline at end of file
